@@ -17,12 +17,13 @@ case_list <- function(eventlog) {
 
 
 case_list.eventlog <- function(eventlog){
+	min_order <- NULL
 
 	eDT <- data.table::as.data.table(eventlog)
 	cases <- eDT[,
-				 list("timestamp_classifier" = min(get(timestamp(eventlog)))),
+				 list("timestamp_classifier" = min(get(timestamp(eventlog))), "min_order" = min(get(".order"))),
 				 by = list("A" = get(case_id(eventlog)), "B" = get(activity_instance_id(eventlog)), "C" = get(activity_id(eventlog)))]
-	cases <- cases[order(get("timestamp_classifier"), get("C")),
+	cases <- cases[order(get("timestamp_classifier"), min_order),
 				   list(trace = paste(get("C"), collapse = ",")),
 				   by = list("CASE" = get("A"))]
 	cases <- cases %>% mutate(trace_id = as.numeric(factor(!!as.symbol("trace")))) %>%
