@@ -110,12 +110,11 @@ ungroup_eventlog <- function(eventlog) {
 #' @describeIn ungroup_eventlog Remove groups from event log
 #' @export
 ungroup_eventlog.eventlog <- function(eventlog) {
-	eventlog %>%
-		as.data.frame %>%
-		re_map(mapping(eventlog))
+	if (is_grouped_eventlog(eventlog)) {
+		eventlog %>%
+			as.data.frame %>%
+			re_map(mapping(eventlog))
+	} else {
+		eventlog
+	}
 }
-
-
-
-
-
