@@ -1,6 +1,6 @@
 #' @title Re map
 #'
-#' @description Construct and eventlog using an existing mapping.
+#' @description Construct an eventlog using an existing mapping.
 #'
 #' @param eventlog The event log data to be used.
 #'
@@ -16,5 +16,6 @@ re_map <- function(eventlog, eventlog_mapping) {
 			lifecycle_id = eventlog_mapping$lifecycle_identifier,
 			timestamp = eventlog_mapping$timestamp_identifier,
 			resource_id = eventlog_mapping$resource_identifier,
-			order = ".order")
+			order = ".order",
+			validate = FALSE) # assumes that data is OK upon for `re_map`
 }
