@@ -10,3 +10,11 @@ activity_instance_id_ <- function(eventlog) sym(activity_instance_id(eventlog))
 resource_id_ <- function(eventlog) sym(resource_id(eventlog))
 timestamp_ <- function(eventlog) sym(timestamp(eventlog))
 lifecycle_id_ <- function(eventlog) sym(lifecycle_id(eventlog))
+
+is_eventlog <- function(eventlog) {
+	"eventlog" %in% class(eventlog)
+}
+
+is_grouped_eventlog <- function(eventlog) {
+	"grouped_eventlog" %in% class(eventlog)
+}
